==> rD3plot_1.0.10.tar.gz: rD3plot/inst/www/en.js <==
// texts to translate
var texts = {
    graph : "Graph",
    nodes : "Nodes",
    general: "General",
    links: "Links",
    apply: "Apply",
    filter: "Filter",
    isolate: "Isolate",
    select: "Select",
    clear: "Clear",
    add: "Add",
    nodesattributes: "Node attributes",
    linksattributes: "Link attributes",
    noitemsselected: "Select a node in the graph to see its attributes.",
    repulsion: "Repulsion",
    distance: "Distance",
    loading: "Loading...",
    pdfexport: "PDF export",
    svgexport: "SVG export",
    pngexport: "PNG export",
    showHelp: "Show help",
    showhidelegend: "Legend",
    showhideaxes: "Axes",
    showhidesidebar: "Show/hide sidebar",
    showhidebuttons: "Show/hide buttons",
    showhidetables: "Show/hide tables",
    stopresume: "Dynamic",
    heatmap: "Heatmap",
    resetfilter: "Remove filters",
    selectall: "Select all",
    selectneighbors: "Add neighbors",
    expand: "Expand",
    collapse: "Collapse",
    Reverse: "Reverse",
    tableselection: "Matched in table",
    reset: "Reset",
    directional: "Arrows",
    degree: "degree",
    none: "none",
    default: "default",
    downloadtable: "Download table",
    total: "Total",
    concoincidences: "Conditional coincidences",
    coincidences: "Coincidences",
    ofsomeone: "of",
    withsomeone: "with",
    incidences: "Incidences",
    expected: "Expected",
    expectedconfidence: "+/- Expected confidence",
    confidenceinterval: "+/- Confidence interval",
    subjectselect: "Event",
    Label: "Label",
    LabelSize: "Lab.Size",
    Group: "Group",
    Order: "Order",
    Size: "Size",
    Color: "Color",
    Shape: "Shape",
    Legend: "Legend",
    Image: "Image",
    Width: "Width",
    Weight: "Weight",
    Intensity: "Intensity",
    Text: "Text",
    LabelInfo: "Label",
    LabelSizeInfo: "Label Size",
    GroupInfo: "Group",
    OrderInfo: "Order",
    SizeInfo: "Size",
    ColorInfo: "Color",
    ShapeInfo: "Shape",
    LegendInfo: "Legend",
    WidthInfo: "Width",
    WeightInfo: "Weight",
    IntensityInfo: "Intensity",
    TextInfo: "Text",
    Layout: "Layout",
    LayoutInfo: "Layout",
    Show: "Show",
    Hide: "Hide",
    circle: "circle",
    cross: "cross",
    diamond: "diamond",
    square: "square",
    "triangle-down": "triangle-down",
    "triangle-up": "triangle-up",
    trianglesquare: "Triangle",
    selectacolorscale: "Select a color scale for ",
    selectacolor: "Select a color for ",
    selectashape: "Select a shape for ",
    selectattribute: "Select an attribute to display as ",
    outof: "out of",
    scenarios: "Number of scenarios",
    resetzoom: "Reset zoom",
    zoomin: "Zoom in",
    zoomout: "Zoom out",
    removefilter: "Remove filter",
    alertrecordheatmap: "Heatmap cannot be recorded.",
    speed: "Speed",
    searchanode: "Search a node",
    goback: "Return",
    newtab: "Open in new tab",
    tools: "Tools",
    poweredby: "Powered by",
    isolateInfo: "Allows you to see only the selected node (or nodes)",
    filterInfo: "Allows you to see the selected node (or nodes) and its network (nodes with which it is related)",
    selectcustomcolor: "Select a custom color",
    filterselection: "Filter selection",
    Elements: "Elements"
  };

==> rD3plot_1.0.22.tar.gz: rD3plot/inst/www/en.js <==
// texts to translate
var texts = {
    graph : "Graph",
    nodes : "Nodes",
    general: "General",
    links: "Links",
    apply: "Apply",
    filter: "Filter",
    isolate: "Isolate",
    select: "Select",
    clear: "Clear",
    add: "Add",
    nodesattributes: "Node attributes",
    linksattributes: "Link attributes",
    noitemsselected: "Select a node in the graph to see its attributes.",
    repulsion: "Repulsion",
    distance: "Distance",
    loading: "Loading...",
    pdfexport: "PDF export",
    svgexport: "SVG export",
    pngexport: "PNG export",
    showHelp: "Show help",
    showhidelegend: "Legend",
    showhideaxes: "Axes",
    showhidesidebar: "Show/hide sidebar",
    showhidebuttons: "Show/hide buttons",
    showhidetables: "Show/hide tables",
    stopresume: "Dynamic",
    heatmap: "Heatmap",
    resetfilter: "Remove filters",
    selectall: "Select all",
    selectneighbors: "Add neighbors",
    expand: "Expand",
    collapse: "Collapse",
    Reverse: "Reverse",
    tableselection: "Matched in table",
    reset: "Reset",
    directional: "Arrows",
    degree: "degree",
    none: "none",
    default: "default",
    downloadtable: "Download table",
    total: "Total",
    concoincidences: "Conditional coincidences",
    coincidences: "Coincidences",
    ofsomeone: "of",
    withsomeone: "with",
    incidences: "Incidences",
    expected: "Expected",
    expectedconfidence: "+/- Expected confidence",
    confidenceinterval: "+/- Confidence interval",
    subjectselect: "Event",
    Label: "Label",
    LabelSize: "Lab.Size",
    Group: "Group",
    Order: "Order",
    Size: "Size",
    Color: "Color",
    Shape: "Shape",
    Legend: "Legend",
    Image: "Image",
    Width: "Width",
    Weight: "Weight",
    Intensity: "Intensity",
    Text: "Text",
    LabelInfo: "Label",
    LabelSizeInfo: "Label Size",
    GroupInfo: "Group",
    OrderInfo: "Order",
    SizeInfo: "Size",
    ColorInfo: "Color",
    ShapeInfo: "Shape",
    LegendInfo: "Legend",
    WidthInfo: "Width",
    WeightInfo: "Weight",
    IntensityInfo: "Intensity",
    TextInfo: "Text",
    Layout: "Layout",
    LayoutInfo: "Layout",
    Show: "Show",
    Hide: "Hide",
    circle: "circle",
    cross: "cross",
    diamond: "diamond",
    square: "square",
    "triangle-down": "triangle-down",
    "triangle-up": "triangle-up",
    trianglesquare: "Triangle",
    selectacolorscale: "Select a color scale for ",
    selectacolor: "Select a color for ",
    selectashape: "Select a shape for ",
    selectattribute: "Select an attribute to display as ",
    outof: "out of",
    scenarios: "Number of scenarios",
    resetzoom: "Reset zoom",
    zoomin: "Zoom in",
    zoomout: "Zoom out",
    removefilter: "Remove filter",
    alertrecordheatmap: "Heatmap cannot be recorded.",
    speed: "Speed",
    searchanode: "Search a node",
    goback: "Return",
    newtab: "Open in new tab",
    tools: "Tools",
    poweredby: "Powered by",
    isolateInfo: "Allows you to see only the selected node (or nodes)",
    filterInfo: "Allows you to see the selected node (or nodes) and its network (nodes with which it is related)",
    selectcustomcolor: "Select a custom color",
    filterselection: "Filter selection",
    Elements: "Elements",
    Deselect: "Deselect",
    more: "more",
    less: "less",
    Scale: "Scale"
  };
